#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname signedjson
%bcond_without python2
%{?sle15_python_module_pythons}
Name:           python-%{modname}
Version:        1.1.4
Release:        3.3
Summary:        Python module to sign JSON with Ed25519 signatures
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/matrix-org/%{name}
Source0:        https://files.pythonhosted.org/packages/source/s/signedjson/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyNaCl >= 0.3.0
Requires:       python-canonicaljson >= 1.0.0
Requires:       python-importlib-metadata
Requires:       python-typing_extensions >= 3.5
Requires:       python-unpaddedbase64 >= 1.0.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyNaCl >= 0.3.0}
BuildRequires:  %{python_module canonicaljson >= 1.0.0}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions >= 3.5}
BuildRequires:  %{python_module unpaddedbase64 >= 1.0.1}
# /SECTION
%if %{with python2}
BuildRequires:  python2-typing >= 3.5
%endif
%ifpython2
Requires:       python-typing >= 3.5
%endif
%python_subpackages

%description
Features:

* More than one entity can sign the same object.
* Each entity can sign the object with more than one key making it easier to
  rotate keys
* ED25519 can be replaced with a different algorithm.
* Unprotected data can be added to the object under the "unsigned" key.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/signedjson
%{python_sitelib}/signedjson-%{version}*-info

%changelog
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Feb 21 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
* Wed Jun  8 2022 Marcus Rueckert <mrueckert@suse.de>
- reenable testsuite
* Tue Jun  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.1.4
  - Bugfixes
  - Fix a bug introduced in signedjson 1.1.3 where signedjson
    could not be imported due to an MRO resolution error. (#22)
  - Do not require importlib_metadata on Python 3.8 and above. By
    @MeggyCal. (#9)
  - Internal Changes
  - Configure @matrix-org/synapse-core to be the code owner for
    the repository. (#11)
  - Use assertEqual for Python 3.11. By @hugovk. (#17)
  - Run linters (flake8, mypy, black, isort). (#20)
  - Mark the package as containing type hints. (#20)
- drop no-importlib-on-py38.patch:
  included in update
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.1.1
  * Fix incorrect typing annotation for `decode_signing_key_base64`.
  * Reinstate `decode_verify_key_base64` function which was erroneously removed in 1.1.0.
- Add no-importlib-on-py38.patch to fix build on Python 3.8
* Thu Feb  6 2020 okurz@suse.com
- Update to version 1.1.0:
  * Add type definitions to make it easier to use static type
    checkers.
  * Remove unused `decode_verify_key_base64` method.
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Feb 27 2017 okurz@suse.com
- Initial submission
